/*

*/

import renderer.scene.*;
import renderer.pipeline.*;
import renderer.framebuffer.*;

import java.awt.Color;

/**
   This program demonstrates a problem with the
   way depth is interpolated across a line segment
   when using a perspective projection.

*/
public class SomethingWrong4
{
   public static void main(String[] args)
   {
      // Create a Model object to hold the geometry.
      Model model = new Model();

      double z = -0.0001;

      // Add the geometry (in model coordinates) to the Model.
      Vertex v0 = new Vertex( z, 0.0,  z);
      Vertex v1 = new Vertex(-z, 0.0,  z);
      Vertex v2 = new Vertex(-1, 0.0, -1);
      Vertex v3 = new Vertex(-z/(2+z), 0.0, z/(2-z));

      v0.setColor(Color.red);
      v1.setColor(Color.red);
      v2.setColor(Color.blue);
      v3.setColor(Color.blue);

      model.addLineSegment(v0, v1);
      model.addLineSegment(v2, v3);


      // Create the Scene object that we shall render.
      Scene scene = new Scene();

      // Add the Model to the Scene.
      scene.addPosition(new Position(model));


      // Create a FrameBuffer to render our scene into.
      int width  = 512;
      int height = 512;
      FrameBuffer fb = new FrameBuffer(width, height);

      // Give the framebuffer a background color.
      fb.clearFB(java.awt.Color.darkGray);
      // Render our scene into the frame buffer using a Perspective Projection.
      Pipeline.debug = true;
      Rasterize.debug = true;
      Pipeline.render(scene, fb);
      // Save the resulting image in a file.
      fb.dumpFB2File( "SomethingWrong4.ppm" );
   }
}
