/*

*/

package renderer.models_T;
import  renderer.scene.*;

import java.awt.Color;

/**
   Create a positive x, y, and z axis in 3-dimensional space.
*/
public class Axes3D extends Model
{
   /**
      Create a positive x, y, and z axis
      with one unit length for each axis.
      The default color is black.
   */
   public Axes3D( )
   {
      this(1.0, 1.0, 1.0);
   }


   /**
      Create a positive x, y, and z axis
      with the given length for each axis.
      The default color is black.

      @param xMax  length of the x-axis
      @param yMax  length of the y-axis
      @param zMax  length of the z-axis
   */
   public Axes3D(double xMax, double yMax, double zMax)
   {
      this(xMax, yMax, zMax, Color.black);
   }


   /**
      Create a positive x, y, and z axis
      with the given length for each axis.
      Use the given color for all three axes.

      @param xMax  length of the x-axis
      @param yMax  length of the y-axis
      @param zMax  length of the z-axis
      @param c     color for all three axes
   */
   public Axes3D(double xMax, double yMax, double zMax, Color c)
   {
      this(xMax, yMax, zMax, c, c, c);
   }


   /**
      Create a positive x, y, and z axis
      with the given length for each axis.
      Use the given colors for each axis.

      @param xMax  length of the x-axis
      @param yMax  length of the y-axis
      @param zMax  length of the z-axis
      @param cX    color for the x-axis
      @param cY    color for the y-axis
      @param cZ    color for the z-axis
   */
   public Axes3D(double xMax, double yMax, double zMax,
                 Color cX,    Color cY,    Color cZ)
   {
      this(xMax, 0.0, yMax, 0.0, zMax, 0.0, cX, cY, cZ);
   }


   /**
      Create an x, y, and z axis with the
      given endpoints for each axis.
      The default color is black.

      @param xMax  right endpoint of the x-axis
      @param xMin  left endpoint of the x-axis
      @param yMax  top endpoint of the y-axis
      @param yMin  bottom endpoint of the y-axis
      @param zMax  front endpoint of the z-axis
      @param zMin  back endpoint of the z-axis
   */
   public Axes3D(double xMax, double xMin,
                 double yMax, double yMin,
                 double zMax, double zMin)
   {
      this(xMax, xMin, yMax, yMin, zMax, zMin, Color.black);
   }


   /**
      Create an x, y, and z axis with the
      given endpoints for each axis.
      Use the given Color c.

      @param xMax  right endpoint of the x-axis
      @param xMin  left endpoint of the x-axis
      @param yMax  top endpoint of the y-axis
      @param yMin  bottom endpoint of the y-axis
      @param zMax  front endpoint of the z-axis
      @param zMin  back endpoint of the z-axis
      @param c     color for all three axes
   */
   public Axes3D(double xMax, double xMin,
                 double yMax, double yMin,
                 double zMax, double zMin,
                 Color c)
   {
      this(xMax, xMin, yMax, yMin, zMax, zMin, c, c, c);
   }


   /**
      Create an x, y, and z axis with the
      given endpoints for each axis.
      Use the given colors for each axis.

      @param xMax  right endpoint of the x-axis
      @param xMin  left endpoint of the x-axis
      @param yMax  top endpoint of the y-axis
      @param yMin  bottom endpoint of the y-axis
      @param zMax  front endpoint of the z-axis
      @param zMin  back endpoint of the z-axis
      @param cX    color for the x-axis
      @param cY    color for the y-axis
      @param cZ    color for the z-axis
   */
   public Axes3D(double xMax, double xMin,
                 double yMax, double yMin,
                 double zMax, double zMin,
                 Color cX, Color cY, Color cZ)
   {
      super();

      Vertex x0 = new Vertex(xMin, 0,    0);
      Vertex x1 = new Vertex(xMax, 0,    0);
      Vertex y0 = new Vertex( 0,  yMin,  0);
      Vertex y1 = new Vertex( 0,  yMax,  0);
      Vertex z0 = new Vertex( 0,   0,   zMin);
      Vertex z1 = new Vertex( 0,   0,   zMax);

      x0.setColor( cX );
      x1.setColor( cX );
      y0.setColor( cY );
      y1.setColor( cY );
      z0.setColor( cZ );
      z1.setColor( cZ );

      addLineSegment(x0, x1);
      addLineSegment(y0, y1);
      addLineSegment(z0, z1);
   }
}//Axes3D
