/*

*/

package renderer.models_T;
import  renderer.scene.*;

import java.awt.Color;

/**
   Create a flat checkerboard panel in the xz-plane.
*/
public class Panel extends Model
{
   /**
       Create a flat checkerboard panel in the xz-plane
       with the given dimensions.and without colors.

      @param xMin  location of left edge
      @param xMax  location of right edge
      @param zMin  location of back edge
      @param zMax  location of front edge
   */
   public Panel(int xMin, int xMax, int zMin, int zMax)
   {
      this(xMin, xMax, zMin, zMax, null, null);
   }

   /**
       Create a flat checkerboard panel in the xz-plane
       with the given dimensions and with two colors.

      @param xMin  location of left edge
      @param xMax  location of right edge
      @param zMin  location of back edge
      @param zMax  location of front edge
      @param c1    first {@link Color}
      @param c2    second {@link Color}
   */
   public Panel(int xMin, int xMax, int zMin, int zMax, Color c1, Color c2)
   {
      super();

      // Create the checkerboard's geometry.
      Vertex[][] v = new Vertex[(xMax-xMin)+1][(zMax-zMin)+1];

      for (int x = xMin; x <= xMax; x++)
         for (int z = zMin; z <= zMax; z++)
         {
            v[x-xMin][z-zMin] = new Vertex(x, 0, z);
         }

      // Create the triangles and give each triangle a color.
      for (int x = 0; x < xMax-xMin; x++)
      {
         for (int z = 0; z < zMax-zMin; z++)
         {
            addTriangle( v[x  ][z  ], v[x  ][z+1], v[x+1][z+1] );
            addTriangle( v[x+1][z+1], v[x+1][z  ], v[x  ][z  ] );
            if ( (x+z)%2 == 0 )
            {
               if (null != c1)
               {
                  primitiveList.get(primitiveList.size() - 1).setColor(c1);
                  primitiveList.get(primitiveList.size() - 2).setColor(c1);
               }
            }
            else  // use the other color
            {
               if (null != c2)
               {
                  primitiveList.get(primitiveList.size() - 1).setColor(c2);
                  primitiveList.get(primitiveList.size() - 2).setColor(c2);
               }
            }
         }
      }
   }
}//Panel
