/*

*/

package renderer.pipeline;
import  renderer.scene.*;

import java.util.List;

/**
   Clip a (projected) geometric {@link Primitive} that sticks out of the
   homogeneous clipping region. Interpolate {@link Vertex} color from any
   clipped off {@link Vertex} to the new {@link Vertex}.
*/
public class Clip
{
   public static boolean debug = false;

   /**
      If the {@link Primitive} sticks out of the view rectangle,
      then clip it so that it is contained in the view rectangle.

      @param p  {@link Primitive} to be clipped
      @return a list that is either empty or contains clipped {@link Primitive}s
   */
   public static List<Primitive> clip(Primitive p)
   {
      List<Primitive> result = java.util.Collections.emptyList();

      if (p instanceof Triangle)
      {
         result = ClipTriangle.clip( (Triangle)p );
      }
      else if (p instanceof LineSegment)
      {
         result = ClipLine.clip( (LineSegment)p );
      }
      else
      {
         result = ClipPoint.clip( p );
      }

      return result;
   }
}
