/*

*/

package renderer.pipeline;
import  renderer.scene.*;

import java.util.List;
import java.util.ArrayList;

/**
   Clip a (projected) {@link Point} that sticks out
   of the homogeneous clipping region.
*/
public class ClipPoint
{
   /**
      If the {@link Point} sticks out of the homogeneous clipping region,
      then delete it.

      @param pt  {@link Point} to be clipped
      @return a list that is either empty or contains the given {@link Point}
   */
   public static List<Primitive> clip(Primitive pt)
   {
      boolean debug = Clip.debug;

      List<Primitive> result = new ArrayList<>();

      List<Integer> indexList = new ArrayList<>();

      for (int index : pt.indexList)
      {
         // Make local copies of several values.
         Vertex v = pt.model.vertexList.get(index);

         double x = v.x,  y = v.y,  w = v.w;

         // 1. Check for trivial accept.
         if ( ! ( Math.abs( x ) > Math.abs( w )
               || Math.abs( y ) > Math.abs( w ) ) )
         {
            if (debug) System.out.println(" Trivial accept: " + index);
            indexList.add(index);
         }
         // 2. Trivial delete.
         else
         {
            if (debug) System.out.println(" Trivial delete: " + index);
         }
      }

      if (! indexList.isEmpty())
      {
         pt.indexList = indexList;
         result.add(pt);
      }

      return result;
   }
}
