/*

*/

package renderer.pipeline;
import  renderer.scene.*;

import java.util.List;
import java.util.ArrayList;

/**
   Assemble a {@link Model}'s {@link List} of {@link Primitive}s into a
   {@link List} containing only {@link LineSegment} and {@link Triangle}
   {@link Primitive}s.
<p>
   In order to clip a {@link Face}, we need to first convert
   the {@link Face} into individual {@link LineSegment}s, and
   then clip each line segment separately.
*/
public class PrimitiveAssembly
{
   /**
      Assemble a {@link Model}'s {@link List} of {@link Primitive}s into a
      {@link List} containing only {@link LineSegment} {@link Prinitive}s.

      @param model  {@code Model} whose {@link Primitive}s need to be assembled into {@link LineSegment}s
   */
   public static void assemble(Model model)
   {
      List<Primitive> result = new ArrayList<>();

      for (Primitive p : model.primitiveList)
      {
         if (p instanceof Face)
         {
            // Convert the Face into individual LineSegments.
            for (int i = 0; i < p.indexList.size() - 1; i++)
            {
               result.add(new LineSegment(model, p.indexList.get(i),
                                                 p.indexList.get(i+1)));
            }
            // Close the Face into a loop of line segments.
            result.add(new LineSegment(model, p.indexList.get(p.indexList.size() - 1),
                                              p.indexList.get(0)));
         }
         else if (p instanceof LineSegment)
         {
            result.add(p);
         }
         else if (p instanceof Triangle)
         {
            result.add(p);
         }
      }

      model.primitiveList = result;
   }
}
