/*

*/

package renderer.pipeline;
import  renderer.scene.*;
import  renderer.framebuffer.*;

/**
   Rasterize a geometric {@link Primitive} into
   pixels in the {@link FrameBuffer}'s viewport.
*/
public class Rasterize
{
   public static boolean debug = false;

   /**
      Rasterize a {@link Primitive} into pixels in the
      {@link FrameBuffer}'s viewport.

      @param p   {@code Primitive} to rasterize into the {@code FrameBuffer}
      @param fb  {@code FrameBuffer} to hold rasterized pixels
   */
   public static void rasterize(Primitive p, FrameBuffer fb)
   {
      if (p instanceof Triangle)
      {
         RasterizeTriangle.rasterize( (Triangle)p, fb );
      }
      else if (p instanceof LineSegment)
      {
         if ( Pipeline.doAntialiasing )
         {
            RasterizeLineAntialias.rasterize( (LineSegment)p, fb );
         }
         else
         {
            RasterizeLine.rasterize( (LineSegment)p, fb );
         }
      }
      else
      {
         RasterizePoint.rasterize( p, fb );
      }
   }
}
