/*

*/

package renderer.pipeline;
import  renderer.scene.*;
import  renderer.framebuffer.*;

import java.awt.Color;

/**
   Rasterize a {@link Point} into pixels in the
   {@link FrameBuffer}'s viewport.
*/
public class RasterizePoint
{
   /**
      Rasterize a {@link Point} into pixels in the
      {@link FrameBuffer}'s viewport.

      @param pt  {@code Point} to rasterize into the {@code FrameBuffer}
      @param fb  {@code FrameBuffer} to hold rasterized pixels
   */
   public static void rasterize(Primitive pt, FrameBuffer fb)
   {
      boolean debug = Rasterize.debug;

      int w = fb.getWidthVP();
      int h = fb.getHeightVP();

      for (int index : pt.indexList)
      {
         Vertex v = pt.model.vertexList.get(index);

         // Round the point's coordinates to the nearest logical pixel.
         double x = Math.round( v.x );
         double y = Math.round( v.y );

         // Get this points's depth.
         double z = v.z;

         // Get the z-buffer value currently at this pixel of the viewport.
         double zBuff = fb.getDepthVP((int)x - 1, h - (int)y);

         // If the current fragment is in front of what is in the framebuffer,
         // then overwrite the data in the framebuffer.
         if (z > zBuff)
         {
            // Get the color from the vertex.
            float r = v.r;
            float g = v.g;
            float b = v.b;

            fb.setPixelVP( (int)x - 1,
                           h - (int)y,
                           new Color(r, g, b) );
            fb.setDepthVP( (int)x - 1, h - (int)y, z );

            // log interesting information to standard output
            if (debug) logPixel(w, h, x, y, z, r, g, b);
         }
      }
   }

   private static void logPixel(int w, int h, double x, double y, double z,
                                              float r, float g, float b)
   {
      System.out.printf("[w=%d, h=%d]  x=%f, y=%f, z=%f, r=%f, g=%f, b=%f\n",
                          w, h, x, y, z, r, g, b);
   }
}
