/*

*/

package renderer.scene;

/**
   This is an orthographic (parallel) projection {@link Matrix}.
   <pre>{@code
     [ 1  0  0  0 ]
     [ 0  1  0  0 ]
     [ 0  0  1  0 ]
     [ 0  0  0  1 ]
   }</pre>
   Notice that this is simply the identity matrix and it transforms
   the standard view parallelepiped in camera coordinates into the
   standard view parallelepiped in clip coordinates (which are also
   NDC in this case).
*/
public class OrthographicProjectionMatrix
{
   /**
      This is a static factory method.
      <p>
      Construct this orthographic projection {@link Matrix}.
      <pre>{@code
        [ 1  0  0  0 ]
        [ 0  1  0  0 ]
        [ 0  0  1  0 ]
        [ 0  0  0  1 ]
      }</pre>
   */
   public static Matrix build()
   {
      return Matrix.build(
               new Vector(1.0, 0.0,  0.0, 0.0),
               new Vector(0.0, 1.0,  0.0, 0.0),
               new Vector(0.0, 0.0,  1.0, 0.0),
               new Vector(0.0, 0.0,  0.0, 1.0) );
   }
}
