/*

*/

package renderer.scene;

import java.util.List;
import java.util.ArrayList;

/**
   A {@code Point} object has a list of integers that represent
   points in space. The integers are indices into the {@link Vertex}
   list of a {@link Model} object.
*/
public class Point extends Primitive
{
   /**
      Construct a default (empty) {@code Point}.

      @param model  {@link Model} containing the {@link Vertex} list for the new {@code Point}
   */
   public Point(Model model)
   {
      super(model);
   }


   /**
      Construct a {@code Point} from an array of integer indices.

      @param model   {@link Model} containing the {@link Vertex} list for the new {@code Point}
      @param iArray  array of vertices to put into the new {@code Point}
   */
   public Point(Model model, Integer... iArray)
   {
      super(model, iArray);
   }


   /**
      Construct a {@code Point} from a {@link List} of integer indices.

      @param model  {@link Model} containing the {@link Vertex} list for the new {@code Point}
      @param iList  {@link List} of vertices to put into the new {@code Point}
   */
   public Point(Model model, List<Integer> iList)
   {
      super(model, iList);
   }


   /**
      Implement the makeCopy() method from the abstract base class.
      <p>
      Make a deep copy of this {@code Point} primitive.

      @param newModel  the {@link Model} that the new {@code Point} will be part of
      @return a {@code Point} object that is a deep copy of this {@code Point}
   */
   public Point makeCopy(Model newModel)
   {
      List<Integer> newIndexList = new ArrayList<>(this.indexList.size());
      for (Integer index : this.indexList)
      {
         newIndexList.add(index);
      }
      return new Point(newModel, newIndexList);
   }


   /**
      For debugging.

      @return {@link String} representation of this {@code Point} object
   */
   @Override
   public String toString()
   {
      String result = "Point: (";
      for (Integer index : this.indexList)
      {
         result += index + ", ";
      }
      return result + ")\n";
   }
}
